==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/IAM/GetServerCertificate.pm <==

package Paws::IAM::GetServerCertificate;
  use Moose;
  has ServerCertificateName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetServerCertificate');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IAM::GetServerCertificateResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetServerCertificateResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::GetServerCertificate - Arguments for method GetServerCertificate on L<Paws::IAM>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetServerCertificate on the
L<AWS Identity and Access Management|Paws::IAM> service. Use the attributes of this class
as arguments to method GetServerCertificate.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetServerCertificate.

=head1 SYNOPSIS

    my $iam = Paws->service('IAM');
    my $GetServerCertificateResponse = $iam->GetServerCertificate(
      ServerCertificateName => 'MyserverCertificateNameType',

    );

    # Results:
    my $ServerCertificate = $GetServerCertificateResponse->ServerCertificate;

    # Returns a L<Paws::IAM::GetServerCertificateResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/iam/GetServerCertificate>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ServerCertificateName => Str

The name of the server certificate you want to retrieve information
about.

This parameter allows (per its regex pattern
(http://wikipedia.org/wiki/regex)) a string of characters consisting of
upper and lowercase alphanumeric characters with no spaces. You can
also include any of the following characters: _+=,.@-




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetServerCertificate in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/IAM/GetServerCertificate.pm <==

package Paws::IAM::GetServerCertificate;
  use Moose;
  has ServerCertificateName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetServerCertificate');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IAM::GetServerCertificateResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetServerCertificateResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::GetServerCertificate - Arguments for method GetServerCertificate on L<Paws::IAM>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetServerCertificate on the
L<AWS Identity and Access Management|Paws::IAM> service. Use the attributes of this class
as arguments to method GetServerCertificate.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetServerCertificate.

=head1 SYNOPSIS

    my $iam = Paws->service('IAM');
    my $GetServerCertificateResponse = $iam->GetServerCertificate(
      ServerCertificateName => 'MyserverCertificateNameType',

    );

    # Results:
    my $ServerCertificate = $GetServerCertificateResponse->ServerCertificate;

    # Returns a L<Paws::IAM::GetServerCertificateResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/iam/GetServerCertificate>

=head1 ATTRIBUTES


=head2 B<REQUIRED> ServerCertificateName => Str

The name of the server certificate you want to retrieve information
about.

This parameter allows (through its regex pattern
(http://wikipedia.org/wiki/regex)) a string of characters consisting of
upper and lowercase alphanumeric characters with no spaces. You can
also include any of the following characters: _+=,.@-




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetServerCertificate in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
